@@ -4,8 +4,11 @@ Configuration example for ``ptpython``.
 Copy this file to ~/.ptpython/config.py
 """
 from __future__ import unicode_literals
+from prompt_toolkit.filters import ViInsertMode
+from prompt_toolkit.key_binding.input_processor import KeyPress
 from prompt_toolkit.keys import Keys
 from pygments.token import Token
+
 from ptpython.layout import CompletionVisualisation
 
 __all__ = (
@@ -124,6 +127,14 @@ def configure(repl):
         if b.accept_action.is_returnable:
             b.accept_action.validate_and_handle(event.cli, b)
 
+
+    # Typing 'jj' in Vi Insert mode, should send escape. (Go back to navigation
+    # mode.)
+    @repl.add_key_binding('j', 'j', filter=ViInsertMode())
+    def _(event):
+        " Map 'jj' to Escape. "
+        event.cli.input_processor.feed(KeyPress(Keys.Escape))
+
     """
     # Custom key binding for some simple autocorrection while typing.
     corrections = {
